	clear
	discard
	///////// EXAMPLE 1: RUNNING EUROMOD for BG for policy system of year 2023 /////////
	
	global EUROMOD_PATH = "PATH/WHERE/STATAPLUGIN/IS/LOCATED" // Not using this path will let the command look for the default installation path which is c:\Program Files\EUROMOD\Executable.
	adopath + "PATH/TO/YOUR/ADOFILES" // This is the path where the ado files with the commands are stored. For more information on how this works, use the "help adopath"-command in Stata
	//SYSTEM NAME OF EUROMOD
	global system  "BG_2023" // Name of the System
	global model_path "PATH/TO/YOUR/MODEL" // Path to the model
	global dataset "BG_2021_c1" // Dataset name that you want to run EUROMOD against
	global input_data_path "/PATH/WHER/YOU/KEEP/YOUR/DATA"
	// First example don't use globals or locals
	euromod_run, dataset($dataset) system($system) model($model_path) country(BG) repository($input_data_path) // data can be either loaded through the use of the repository option, or by the import delimited -command. Note that the repository option will clear previoiusly stored data when loading.
	
	// GOOD practice to give the outputdata a prefix when running multiple times
	euromod_run, dataset($dataset) system($system) model($model_path) country(BG) repository($input_data_path) prefix(sim1_)
	
	
	
	
	
	
	
	
	
	///////// EXAMPLE 2: changing a CONSTANT ///////////////////
	global system "SE_2023"
	global dataset "SE_2021_b1"
	euromod_run, dataset($dataset) system($system) model($model_path) country(SE) repository($input_data_path) prefix(sim1_) euro
	su sim1_ils_tax [aw=dwt] 
	global total_tax0 = r(sum)

	euromod_run, dataset($dataset) system($system) model($model_path) country(SE)  constants("tinna_rate1='-0.01'") prefix(sim2_) euro

	su sim2_ils_tax [aw=dwt] 
	global total_tax1 = r(sum)
	di in r $total_tax1
	euromod_run, dataset($dataset) system($system) model($model_path) country(SE)  constants("tinna_rate1='-0.01' tinna_rate2='0.20 + 0.01'") prefix(sim3_) euro
	
	
	
	
	////////// EXAMPLE 3: CONTROLLING extensions //////////////////////////////////
	euromod_run, dataset(SK_2020_b1) country(SK) model($model_path) system(SK_2022) repository($input_data_path) extensions(BTA=off) prefix(sim1_)
	euromod_run, dataset(SK_2020_b1) country(SK) model($model_path) system(SK_2022) extensions(BTA=on) prefix(sim2_)
	su sim*_ben*t
	
	////////// EXAMPLE 4: RUNNING ITT /////////////////////////////////////////
	euromod_run, dataset(SK_2010_x1) country(SK) model($model_path) system(SK_2022) addons(ITT_XBASE|ITT_XBase) repository($input_data_path) prefix(sim1_)
	euromod_getdata, outputdataset(sk_2022_xbase_std.txt) prefix(sim1_)
	euromod_run, dataset(SK_2010_x1) country(SK) model($model_path) system(SK_2022) addons(ITT_XBASE|ITT_XBase) prefix(sim2_) constants("tco_base_t_std(2022)='0.3'") outputdataset(sk_2022_xbase_std.txt)
	su sim*_il_tva
	
	///////// EXAMPLE 5: RUNNING on subsets of the data ///////////////////////
	import delimited "$input_data_path/SE_2021_b1.txt",clear
	// WHEN DOING THIS BE AWARE TO NOT BREAK THE HOUSEHOLD STRUCTURE
	euromod_run if dgn == 0, country(SE) model($model_path) system(SE_2022) dataset(SE_2021_b1) prefix(sim_)
	
	expand 2, generate(counterfactual) // increase number of households	
	replace yem = yem*1.1 if counterfactual == 1
	euromod_run if counterfactual == 0, country(SE) model($model_path) system(SE_2022) dataset(SE_2021_b1) prefix(sim_)
	euromod_run if counterfactual == 1, country(SE) model($model_path) system(SE_2022) dataset(SE_2021_b1) prefix(sim_)
	tabstat sim_ils_dispy, by(counterfactual) statistics(mean median sd min max)

	
	
	//simple bisection algorithm implementation
	//////// EXAMPLE 6: Making a Revenue Neutral Reform  //////////////////////
	import delimited "$input_data_path/SE_2021_b1.txt",clear
	local a = "0.2"
	local b = "0.4"
	local fa = $total_tax1 - $total_tax0
	euromod_run, dataset($dataset) system($system) model($model_path) country(SE)  constants("tinna_rate1='-0.01' tinna_rate2='`b''") prefix(sim2_) euro
	su sim2_ils_tax [aw=dwt]
	local fb = r(sum) - $total_tax0
	di "`fa' , `fb'"
	local ctr = 1
	while `ctr' < 20 {
		local c = (`a' + `b')/2
		qui euromod_run, dataset($dataset) system($system) model($model_path) country(SE)  constants("tinna_rate1='-0.01' tinna_rate2='`c''") prefix(sim3_) euro
		qui su sim3_ils_tax [aw=dwt] 
		local fc= r(sum) - $total_tax0
		di "Iteration `ctr': value `c' and function value `fc'"
		if  abs(`c' - `a') < 0.001  {
			di "found solution at tinna_rate2 = `c'"
			continue, break
		}
		local ctr  = `ctr' + 1	
		if sign(`fc') == sign(`fa') {
			local a = `c'
			local fa = `fc'
		}
		else {
			local b = `c'
			local fb = `fc'
		}	
	}
	
	
	