
quiet{
	
global path ""
global model ""
global system "ES_2023_reform"
global dataset "ES_2021_b1"
global country "ES"
global repository ""

local count = 1

foreach level in 0 1 { 													// 0 = ind, 1 = hh
	foreach type in 0 1 2 { 	 										// 0 = children, 1 = gmi, 2 = pensioners
		foreach poor in 0 1 { 											// 0 = all, 1 = poor only
			foreach revneutral in 0 1 2 { 								// 0 = no, 1 = all, 2 = rich
				foreach b00_amount in 150 300 450 { 					// 150#m, 300#m, 450#m

				// Run EUROMOD!
				euromod_run, model($model) system($system) dataset($dataset) country($country) repository($repository) constants("level = '`level'' type = '`type'' poor = '`poor'' revneutral = '`revneutral'' b00_amount = '`b00_amount''")
				
				// Comput final equivalised disposable income (the one in the output is the baseline one)
				bysort idhh: egen eq_scale_total = total(eq_scale) 		// 	sum hh eq. scale
				local eq_varlist "ils_dispy"							// varlist to equivalise
				recast double ils_dispy									// recast for maximum precision
				bysort idhh: egen hh_ils_dispy = total(ils_dispy)		// aggregate monthly disposable income on the household level
				gen eq_ils_dispy_new = hh_ils_dispy/ eq_scale_total		// equiv. annual disposable income (per household member)
				
				// Compute deciles and mean eq disp income by decile
				xtile decile = eq_ils_dispy_new, nq(10)		
				tabstat eq_ils_dispy_new [aw=dwt], by(decile) save
				
				// Save results in matrix M
				if `count' == 1{
					matrix M = `count', `level', `type', `poor', `revneutral', `b00_amount', r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10)
					matrix colnames M = number level type poor revneutral b00_amount D1 D2 D3 D4 D5 D6 D7 D8 D9 D10
				} 
				else matrix M = M\(`count', `level', `type', `poor', `revneutral', `b00_amount', r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6), r(Stat7), r(Stat8), r(Stat9), r(Stat10))
				
				// Show time and matrix
				nois disp in red "$S_DATE $S_TIME"
				nois matrix list M, noheader noblank
				
				// Count loop round
				local count = `count' + 1
				
				}
			}
		}
	}
}

}

putexcel set "$path\indicators.xlsx", replace
putexcel A1 = matrix(M), colnames